@@ -39,19 +39,24 @@
 #ifndef _ENDPOINT_H_
 #define _ENDPOINT_H_
 
+
 #include "../config.h"
 
 #include "common.h"
-#include "gdkvideoio.h"
-#include "videograbber.h"
-#include "ils.h"
-#include "lid.h"
 
 #ifdef HAS_IXJ
 #include <ixjlid.h>
 #endif
 
 
+#include "gdkvideoio.h"
+#include "videograbber.h"
+
+class GMILSClient;
+class GMLid;
+
+
+
 /**
  * COMMON NOTICE: The Endpoint must be initialized with Init after its
  * creation.
@@ -64,7 +69,7 @@ class GMH323EndPoint : public H323EndPoint
   
  public:
 
-  enum {Standby, Calling, Connected, Called};
+  enum CallingState {Standby, Calling, Connected, Called};
 
   
   /* DESCRIPTION  :  The constructor.
@@ -307,7 +312,7 @@ class GMH323EndPoint : public H323EndPoint
    *                     Called }
    * PRE          :  /
    */
-  void SetCallingState (unsigned);
+  void SetCallingState (CallingState);
 
 
   /* DESCRIPTION  :  /
@@ -318,7 +323,7 @@ class GMH323EndPoint : public H323EndPoint
    *                     Called }
    * PRE          :  /
    */
-  unsigned GetCallingState (void);
+  CallingState GetCallingState (void);
 
 
   /* Overrides from H323Endpoint */
@@ -488,9 +493,9 @@ class GMH323EndPoint : public H323EndPoint
 
   /* DESCRIPTION  :  /
    * BEHAVIOR     :  Create a new Lid.
-   * PRE          :  /
+   * PRE          :  Non-empty device name.
    */
-  void CreateLid ();
+  GMLid *CreateLid (PString);
 #endif
 
 
@@ -541,7 +546,14 @@ class GMH323EndPoint : public H323EndPoint
    */
   PString CheckTCPPorts ();
 
+  
+  /* DESCRIPTION  :  Notifier called after 30 seconds of no media.
+   * BEHAVIOR     :  Clear the calls.
+   * PRE          :  /
+   */
+  PDECLARE_NOTIFIER(PTimer, GMH323EndPoint, OnNoIncomingMediaTimeout);
 
+  
   /* DESCRIPTION  :  Notifier called periodically to update details on ILS.
    * BEHAVIOR     :  Register, unregister the user from ILS or udpate his
    *                 personal data using the GMILSClient (XDAP).
@@ -600,11 +612,12 @@ class GMH323EndPoint : public H323EndPoint
   H323Connection *current_connection;  
   H323ListenerTCP *listener;  
 
-  unsigned calling_state; 
+  CallingState calling_state; 
 
   GDKVideoOutputDevice *transmitted_video_device; 
   GDKVideoOutputDevice *received_video_device; 
 
+  PTimer NoIncomingMediaTimer;
   PTimer ILSTimer;
   PTimer RTPTimer;
   PTimer GatewayIPTimer;
@@ -618,7 +631,11 @@ class GMH323EndPoint : public H323EndPoint
   GmLdapWindow *lw;
   GmTextChat *chat;
 
+
+  /* The encoding video grabber */
   GMVideoGrabber *video_grabber;
+
+  
   GMILSClient *ils_client;
   PThread *audio_tester;
 
@@ -639,11 +656,6 @@ class GMH323EndPoint : public H323EndPoint
 #ifdef HAS_IXJ
   GMLid *lid;
 #endif
-
-  BOOL is_transmitting_video;
-  BOOL is_receiving_video;
-  BOOL is_transmitting_audio;
-  BOOL is_receiving_audio;
 };
 
 #endif
